@@ -3,4 +3,4 @@
 *   Copyright (c) 2021 AUTHOR.
 */
 
-export * from "./CLASS_NAMEHubPredictor"
\ No newline at end of file
+export * from "./CLASS_NAMEPredictor"
\ No newline at end of file
