@@ -1,5 +1,5 @@
 import { MLModelData, MLImageFeature } from "natml"
-import { CLASS_NAMEHubPredictor } from "../src"
+import { CLASS_NAMEPredictor } from "../src"
 
 async function main () {
     // Fetch the model data from NatML Hub
@@ -7,7 +7,7 @@ async function main () {
     // Deserialize the model
     const model = modelData.deserialize();
     // Create the predictor
-    const predictor = new CLASS_NAMEHubPredictor(model);
+    const predictor = new CLASS_NAMEPredictor(model);
     // Predict
     // ...
 }
