@@ -14,22 +14,14 @@ namespace CLASS_NAME.Examples {
         [Header(@"NatML Hub")]
         public string accessKey;
 
-        MLModelData modelData;
-        MLModel model;
-        CLASS_NAMEHubPredictor predictor;
-
         async void Start () {
             Debug.Log("Fetching model from NatML Hub");
-            // Fetch model data from NatML Hub
-            var modelData = await MLModelData.FromHub(
-                "TAG",          // Model tag from when we created the draft on Hub
-                accessKey,          // Get your access key from https://hub.natml.ai/profile
-                cache: false        // Disable caching when implementing the predictor
-            );
+            // Fetch model data from NatML Hub // Get your access key from https://hub.natml.ai/profile
+            var modelData = await MLModelData.FromHub("TAG", accessKey);
             // Deserialize the model
             var model = modelData.Deserialize();
             // Create the predictor
-            var predictor = new CLASS_NAMEHubPredictor(model);
+            var predictor = new CLASS_NAMEPredictor(model);
 
             // Make predictions
             // ...
